@@ -11,12 +11,12 @@
 
 #include "data/theme.h"
 
-int playbackCreate(void);
-void playbackSafeCleanup(void);
-void playbackCleanup(void);
+int create_playback_device(void);
+void playback_safe_cleanup(void);
+void playback_cleanup(void);
 void skip(void);
-void playbackSwitchDecoder(void);
-void playbackShutdown(void);
-void playbackUnloadSongs(UserData *userData);
-void playbackFreeDecoders(void);
-void ensureDefaultThemePack();
+void switch_audio_implementation(void);
+void sound_shutdown(void);
+void unload_songs(UserData *user_data);
+void free_decoders(void);
+void ensure_default_theme_pack();
