@@ -21,12 +21,12 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
-bool isContextInitialized(void);
-int createAudioDevice(void);
-int switchAudioImplementation(void);
-void cleanupAudioContext(void);
-ma_result callReadPCMFrames(ma_data_source *pDataSource, ma_format format,
-                            void *pFramesOut, ma_uint64 framesRead,
-                            ma_uint32 channels, ma_uint64 remainingFrames,
-                            ma_uint64 *pFramesToRead);
+bool is_context_initialized(void);
+int pb_create_audio_device(void);
+int pb_switch_audio_implementation(void);
+void cleanup_audio_context(void);
+ma_result call_read_PCM_frames(ma_data_source *p_data_source, ma_format format,
+                               void *p_frames_out, ma_uint64 frames_read,
+                               ma_uint32 channels, ma_uint64 remaining_frames,
+                               ma_uint64 *p_frames_to_read);
 #endif
