@@ -5,8 +5,8 @@
  * Contains the function that shows the welcome screen and sets the path for the first time.
  */
 
- #include <stdbool.h>
+#include <stdbool.h>
 
-void removeArgElement(char *argv[], int index, int *argc);
-void handleOptions(int *argc, char *argv[], bool *exactSearch);
-void setMusicPath(void);
+void remove_arg_element(char *argv[], int index, int *argc);
+void handle_options(int *argc, char *argv[], bool *exact_search);
+void set_music_path(void);
